==> haskell-path-io-1.6.2-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.6.2
visibility:           public
id:                   path-io-1.6.2-ETquX4Qs1nd54mFyWHUr9g
key:                  path-io-1.6.2-ETquX4Qs1nd54mFyWHUr9g
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  20eddb6bf8ca5df4861b0eec5d80e4d8
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-8.10.4/site-local/path-io-1.6.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/path-io-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/path-io-1.6.2
hs-libraries:         HSpath-io-1.6.2-ETquX4Qs1nd54mFyWHUr9g
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    dlist-1.0-KFY6kePYM7gDQLIElBL83C exceptions-0.10.4 filepath-1.4.2.1
    path-0.8.0-zbV8WWs1XbJpryDt1r3Up
    temporary-1.3-7D6eUd59nrdDdMitYScslJ time-1.9.3
    transformers-0.5.6.2 unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.6.2-73-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.6.2
visibility:           public
id:                   path-io-1.6.2-CyfEcqNa76M1QzrCSgSZ4r
key:                  path-io-1.6.2-CyfEcqNa76M1QzrCSgSZ4r
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  1e17f6f8c5998719424a8afb394d42d7
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-8.10.4/site-local/path-io-1.6.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/path-io-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/path-io-1.6.2
hs-libraries:         HSpath-io-1.6.2-CyfEcqNa76M1QzrCSgSZ4r
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    dlist-1.0-KFY6kePYM7gDQLIElBL83C exceptions-0.10.4 filepath-1.4.2.1
    path-0.8.0-1Nzl5yxQbHAI0MmxfQC8pa
    temporary-1.3-YlcfNISBGv11xPHCq9h8q time-1.9.3 transformers-0.5.6.2
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
